Class: Storazzo::RicDiskSampleConfig

Inherits:
RicDiskConfig show all
Defined in:
lib/storazzo/ric_disk_sample_config.rb

Overview

This is a singleton class. You call me this way..

You call me with:

Storazzo::RicDiskSampleConfig.instance()

It loads a sample config in local gem etc/. Usuful for testing or if no other config is found..

Constant Summary

Constants inherited from RicDiskConfig

Storazzo::RicDiskConfig::DEFAULT_CONFIG_LOCATIONS, Storazzo::RicDiskConfig::DefaultConfigLocation, Storazzo::RicDiskConfig::DefaultGemLocationForTests

Constants included from Colors

Colors::PREPEND_ME

Instance Attribute Summary

Attributes inherited from RicDiskConfig

#config, #config_file, #load_called, #project_id

Instance Method Summary collapse

Methods inherited from RicDiskConfig

#already_loaded?, #config_default_folder, #config_hash, #config_project_id, #config_ver, #gcs_enabled?, gem_default_config_path, #get_bucket_paths, #get_config, get_config, #get_local_folders, #iterate_through_file_list_for_disks, safe_instance, #to_s, #to_verbose_s

Methods included from Colors

#azure, #blue, #deb2, #gray, #green, #orange, #pgreen, #pred, #purple, #pwhite, #pyellow, #red, #white, #yellow

Methods included from Common

#bug, #deb, #err, #fatal, #if_deb?, #linux?, #mac?, #ppp, #pverbose, #warn

Instance Method Details

#loadObject

_sample_version



21
22
23
24
# File 'lib/storazzo/ric_disk_sample_config.rb', line 21

def load
  deb("[RicDiskSampleConfig] Wheew 1! We're NOT destroying the world here. We're actually instancing a second Singleton which is a child of the mother, and this time doing things nicely and Rubily.")
  super(DefaultGemLocationForTests, verbose: false)
end

#load_sample_versionObject



26
27
28
29
# File 'lib/storazzo/ric_disk_sample_config.rb', line 26

def load_sample_version
  deb white("[RicDiskSampleConfig] Wheew 2! We're NOT destroying the world here. We're actually instancing a second Singleton which is a child of the mother, and this time doing things nicely and Rubily.")
  super(DefaultGemLocationForTests, verbose: false)
end